==> bes-3.6.2.tar.gz: bes-3.6.2/dispatch/BESDDSResponse.h <==
// BESDDSResponse.h

// This file is part of bes, A C++ back-end server implementation framework
// for the OPeNDAP Data Access Protocol.

// Copyright (c) 2004,2005 University Corporation for Atmospheric Research
// Author: Patrick West <pwest@ucar.edu> and Jose Garcia <jgarcia@ucar.edu>
//
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.
// 
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
// 
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// You can contact University Corporation for Atmospheric Research at
// 3080 Center Green Drive, Boulder, CO 80301
 
// (c) COPYRIGHT University Corporation for Atmospheric Research 2004-2005
// Please read the full copyright statement in the file COPYRIGHT_UCAR.
//
// Authors:
//      pwest       Patrick West <pwest@ucar.edu>
//      jgarcia     Jose Garcia <jgarcia@ucar.edu>

#ifndef I_BESDDSResponse
#define I_BESDDSResponse 1

#include "BESResponseObject.h"
#include "DDS.h"
#include "ConstraintEvaluator.h"

using namespace libdap ;

/** @brief Represents an OPeNDAP DDS DAP2 data object within the BES
 */
class BESDDSResponse : public BESResponseObject
{
private:
    DDS *			_dds ;
    ConstraintEvaluator		_ce ;
public:
    				BESDDSResponse( DDS *dds )
				    : BESResponseObject(),
				      _dds( dds ) {}
    virtual			~BESDDSResponse() ;

    virtual void		dump( ostream &strm ) const ;

    DDS *			get_dds() { return _dds ; }
    ConstraintEvaluator &	get_ce() { return _ce ; }
} ;

#endif // I_BESDDSResponse

==> bes-3.9.0.tar.gz: bes-3.9.0/dispatch/BESDDSResponse.h <==
// BESDDSResponse.h

// This file is part of bes, A C++ back-end server implementation framework
// for the OPeNDAP Data Access Protocol.

// Copyright (c) 2004-2009 University Corporation for Atmospheric Research
// Author: Patrick West <pwest@ucar.edu> and Jose Garcia <jgarcia@ucar.edu>
//
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// You can contact University Corporation for Atmospheric Research at
// 3080 Center Green Drive, Boulder, CO 80301

// (c) COPYRIGHT University Corporation for Atmospheric Research 2004-2005
// Please read the full copyright statement in the file COPYRIGHT_UCAR.
//
// Authors:
//      pwest       Patrick West <pwest@ucar.edu>
//      jgarcia     Jose Garcia <jgarcia@ucar.edu>

#ifndef I_BESDDSResponse
#define I_BESDDSResponse 1

#include "BESDapResponse.h"
#include <DDS.h>
#include <ConstraintEvaluator.h>

using namespace libdap ;

/** @brief Represents an OPeNDAP DDS DAP2 data object within the BES
 */
class BESDDSResponse: public BESDapResponse {
    private:
        DDS * _dds;
        ConstraintEvaluator _ce;
    public:
        BESDDSResponse(DDS *dds) :
            BESDapResponse(), _dds(dds)
        {
        }
        virtual ~BESDDSResponse();

        virtual void set_container(const string &cn);
        virtual void clear_container();

        virtual void dump(ostream &strm) const;

        DDS * get_dds()
        {
            return _dds;
        }
        ConstraintEvaluator & get_ce()
        {
            return _ce;
        }
};

#endif // I_BESDDSResponse
